#!/etc/opt/openit/perl -w
###############################################################################
#
# Add new diretive to
#
#  /var/opt/openit/etc/openit.cfg
#
# Takes
#
#  - Directive name
#  - Directive value
#
# as parameters.
#
# No changes are done if diretive already exists
#
###############################################################################

use strict;

my $directive = $ARGV[ 0 ];
my $value     = $ARGV[ 1 ];

my $new_directive = "$directive  $value\n";

my $cfg = "/etc/opt/openit/openit.cfg";
my $old = "/etc/opt/openit/openit.cfg.old";
my $new = "/etc/opt/openit/openit.cfg.new";

my @cfg = (); # Hold config


&verify_root();
&read_cfg();

if( &directive_exists($directive) ) {
    print "Directive '$directive' exists, skipping update!\n";
    exit 0;
}

# Add new directive at end
push @cfg, $new_directive;

&write_cfg();

if( ! rename($cfg, $old)) {
    die "Error: Unable to previous config to '$old'!\n";
}

if( ! rename($new, $cfg)) {
    die "Error: Unable to rename new config to '$cfg'!\n";
}

exit 0;


###############################################################################
#
# Only root can run update
#
sub verify_root {
    # Only root can patch
    if ( $< ne 0 ) {
	die "Error: Patching must be done as 'root'!\n";
    }
}


###############################################################################
#
# Read the existing config
#
sub read_cfg {
    open(IN, "<$cfg") || die "Error: Unable to read old cfg '$cfg'!\n";
    while(my $line = <IN>) {
	push @cfg, $line;
    }
    close(IN);
}


###############################################################################
#
# Check if directive exists
#
sub directive_exists {
    my ($directive) = @_;

    foreach my $line (@cfg) {
	if ( $line =~/^$directive/) {
	    return 1;
	}
    }

    return 0;
}


###############################################################################
#
# Write updated file
#
sub write_cfg {
    open(OUT, ">$new") || die "Error: Can't write new cfg '$new'!\n";

    foreach my $line (@cfg) {
	print OUT $line;
    }
    close(OUT);
}
